//Source file: PAMACPSEventData.java
//Date: January 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.4.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to agent capability presence set events. The event is registered for changes in any of the named attributes. If no attributes are named, then the event is registered for all attributes in the presence information.
 * 
 */
public final class PAMACPSEventData implements java.io.Serializable {

    private String[] agentName;
    private String[] agentType;
    private String[] capabilities;
    private String[] attributeNames;
    private long reportingPeriod;

    /**
     * Creates a new PAMACPSEventData instance.
     */
    public PAMACPSEventData () {}

    /**
     * Creates a new PAMACPSEventData instance.
     * @param _agentName   Specifies the name of the agent for which the capability presence change is to be notified. Can be an empty array if notification is required for any agent instance.
     * @param _agentType   Specifies the type of the agent for which this notification is requested if the agentName is specified as an empty array. Can be an empty array if notification required for agents of any type.
     * @param _capabilities   Specifies the capabilities of interest. Can be an empty array if notifications are required for any capability.
     * @param _attributeNames   Specifies attributes of interest. Can be an empty array
     * @param _reportingPeriod   Specifies the interval for periodic reporting (regardless of change). If -1, the event notification happens only on a change. If 0, there is a single immediate notification.
     */
    public PAMACPSEventData (String[] _agentName, String[] _agentType, String[] _capabilities, String[] _attributeNames, long _reportingPeriod) {

        this.agentName = _agentName;
        this.agentType = _agentType;
        this.capabilities = _capabilities;
        this.attributeNames = _attributeNames;
        this.reportingPeriod = _reportingPeriod;
    }

    /**
     * This method returns a agentName.
     * 
     * @return a String[] value
     */
    public String[] getAgentName() {
        return agentName;
    }

    /**
     * This method returns a agentType.
     * 
     * @return a String[] value
     */
    public String[] getAgentType() {
        return agentType;
    }

    /**
     * This method returns a capabilities.
     * 
     * @return a String[] value
     */
    public String[] getCapabilities() {
        return capabilities;
    }

    /**
     * This method returns a attributeNames.
     * 
     * @return a String[] value
     */
    public String[] getAttributeNames() {
        return attributeNames;
    }

    /**
     * This method returns a reportingPeriod.
     * 
     * @return a long value
     */
    public long getReportingPeriod() {
        return reportingPeriod;
    }


    /**
     * This method sets a agentName.
     */ 
    public void setAgentName(String[] agentName) {
        this.agentName = agentName;
    }

    /**
     * This method sets a agentType.
     */ 
    public void setAgentType(String[] agentType) {
        this.agentType = agentType;
    }

    /**
     * This method sets a capabilities.
     */ 
    public void setCapabilities(String[] capabilities) {
        this.capabilities = capabilities;
    }

    /**
     * This method sets a attributeNames.
     */ 
    public void setAttributeNames(String[] attributeNames) {
        this.attributeNames = attributeNames;
    }

    /**
     * This method sets a reportingPeriod.
     */ 
    public void setReportingPeriod(long reportingPeriod) {
        this.reportingPeriod = reportingPeriod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMACPSEventData)) {
            return false;
        } 
        PAMACPSEventData pAMACPSEventData = (PAMACPSEventData) o;
        if(!(this.agentName == pAMACPSEventData.agentName))  {
            return false;
        }
        if(!(this.capabilities == pAMACPSEventData.capabilities))  {
            return false;
        }
        if(!(this.reportingPeriod == pAMACPSEventData.reportingPeriod))  {
            return false;
        }
        if(!(this.attributeNames == pAMACPSEventData.attributeNames))  {
            return false;
        }
        if(!(this.agentType == pAMACPSEventData.agentType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMACPSEventData

