//Source file: PAMErrorCause.java
//Date: January 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.4.0

package org.csapi.jr.se.pam;

/**
 * This defines the types of errors reported by PAM.
 *
 */
public final class PAMErrorCause implements java.io.Serializable {

    private int _value;
    private static int _size = 5;
    private static PAMErrorCause[] _array = new PAMErrorCause[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PAMErrorCause(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _PAM_CAUSE_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final PAMErrorCause PAM_CAUSE_UNDEFINED = new PAMErrorCause(_PAM_CAUSE_UNDEFINED);

    /**
     * The request cannot be handled because the address specified is not valid.
     */
    public static final int _PAM_CAUSE_INVALID_ADDRESS =  1;

    /**
     * The request cannot be handled because the address specified is not valid.
     */
    public static final PAMErrorCause PAM_CAUSE_INVALID_ADDRESS = new PAMErrorCause(_PAM_CAUSE_INVALID_ADDRESS);

    /**
     * System failure.
The request cannot be handled because of a general problem in the service or in the underlying network.
     */
    public static final int _PAM_CAUSE_SYSTEM_FAILURE =  2;

    /**
     * System failure.
The request cannot be handled because of a general problem in the service or in the underlying network.
     */
    public static final PAMErrorCause PAM_CAUSE_SYSTEM_FAILURE = new PAMErrorCause(_PAM_CAUSE_SYSTEM_FAILURE);

    /**
     * The information is currently not available. 
     */
    public static final int _PAM_CAUSE_INFO_UNAVAILABLE =  3;

    /**
     * The information is currently not available. 
     */
    public static final PAMErrorCause PAM_CAUSE_INFO_UNAVAILABLE = new PAMErrorCause(_PAM_CAUSE_INFO_UNAVAILABLE);

    /**
     * The registration for the event has been cancelled by the service.
     */
    public static final int _PAM_CAUSE_EVENT_REGISTRATION_CANCELLED =  4;

    /**
     * The registration for the event has been cancelled by the service.
     */
    public static final PAMErrorCause PAM_CAUSE_EVENT_REGISTRATION_CANCELLED = new PAMErrorCause(_PAM_CAUSE_EVENT_REGISTRATION_CANCELLED);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PAMErrorCause object
     */
    public String getValueText() {
        switch (_value) {
            case _PAM_CAUSE_UNDEFINED:
                return "PAM_CAUSE_UNDEFINED";
            case _PAM_CAUSE_INVALID_ADDRESS:
                return "PAM_CAUSE_INVALID_ADDRESS";
            case _PAM_CAUSE_SYSTEM_FAILURE:
                return "PAM_CAUSE_SYSTEM_FAILURE";
            case _PAM_CAUSE_INFO_UNAVAILABLE:
                return "PAM_CAUSE_INFO_UNAVAILABLE";
            case _PAM_CAUSE_EVENT_REGISTRATION_CANCELLED:
                return "PAM_CAUSE_EVENT_REGISTRATION_CANCELLED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PAMErrorCause getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMErrorCause)) {
            return false;
        }
        PAMErrorCause pAMErrorCause = (PAMErrorCause) o; 
        if(!(this.getValue() == pAMErrorCause.getValue())) {
            return false;
        }
        if (this.hashCode() != pAMErrorCause.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMErrorCause

