//Source file: PAMIDEventData.java
//Date: January 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.4.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to identity deletions. The event is registered for changes in any of the named identities. If no identities are named, then the event is registered for all agents.
 * 
 */
public final class PAMIDEventData implements java.io.Serializable {

    private String[] identityName;
    private String[] identityType;

    /**
     * Creates a new PAMIDEventData instance.
     */
    public PAMIDEventData () {}

    /**
     * Creates a new PAMIDEventData instance.
     * @param _identityName   Specifies the name of the identity whose deletion is to be notified. Can be an empty array.
     * @param _identityType   Specifies the type of the identity for which this notification is requested if identityName is an empty array. Can be an empty array if notification required for identities of any type.
     */
    public PAMIDEventData (String[] _identityName, String[] _identityType) {

        this.identityName = _identityName;
        this.identityType = _identityType;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }


    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMIDEventData)) {
            return false;
        } 
        PAMIDEventData pAMIDEventData = (PAMIDEventData) o;
        if(!(this.identityName == pAMIDEventData.identityName))  {
            return false;
        }
        if(!(this.identityType == pAMIDEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMIDEventData

