//Source file: PAMWCEventData.java
//Date: January 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.4.0

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to watchers changed events.
 * 
 */
public final class PAMWCEventData implements java.io.Serializable {

    private org.csapi.jr.se.pam.PAMEventName[] events;
    private String[] identityName;
    private String[] identityType;
    private long reportingPeriod;

    /**
     * Creates a new PAMWCEventData instance.
     */
    public PAMWCEventData () {}

    /**
     * Creates a new PAMWCEventData instance.
     * @param _events   Specifies the list of events for which the watchers are to be monitored. Can be an empty array if notification is required for watchers to any event.
     * @param _identityName   Specifies the name of an identity for whom the change in watchers is to be notified. Can be an empty array if notification is required for any identity instance.
     * @param _identityType   Specifies the type of the identity for which this notification is requested if the identityName is specified as an empty array. Can be an empty array if notification required for identities of any type.
     * @param _reportingPeriod   Specifies the interval for periodic reporting (regardless of change). If -1, the event notification happens only on a change. If 0, there is a single immediate notification even if there is no change. For all other values, there is a periodic notification at the specified time interval regardless of change.
     */
    public PAMWCEventData (org.csapi.jr.se.pam.PAMEventName[] _events, String[] _identityName, String[] _identityType, long _reportingPeriod) {

        this.events = _events;
        this.identityName = _identityName;
        this.identityType = _identityType;
        this.reportingPeriod = _reportingPeriod;
    }

    /**
     * This method returns a events.
     * 
     * @return a org.csapi.jr.se.pam.PAMEventName[] value
     */
    public org.csapi.jr.se.pam.PAMEventName[] getEvents() {
        return events;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }

    /**
     * This method returns a reportingPeriod.
     * 
     * @return a long value
     */
    public long getReportingPeriod() {
        return reportingPeriod;
    }


    /**
     * This method sets a events.
     */ 
    public void setEvents(org.csapi.jr.se.pam.PAMEventName[] events) {
        this.events = events;
    }

    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }

    /**
     * This method sets a reportingPeriod.
     */ 
    public void setReportingPeriod(long reportingPeriod) {
        this.reportingPeriod = reportingPeriod;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMWCEventData)) {
            return false;
        } 
        PAMWCEventData pAMWCEventData = (PAMWCEventData) o;
        if(!(this.events == pAMWCEventData.events))  {
            return false;
        }
        if(!(this.identityName == pAMWCEventData.identityName))  {
            return false;
        }
        if(!(this.reportingPeriod == pAMWCEventData.reportingPeriod))  {
            return false;
        }
        if(!(this.identityType == pAMWCEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMWCEventData

