//Source file: PAMwatcherChangeType.java
//Date: January 2004
//Presence and Availabilty Management Data Types for 3GPP TS 29.198-14 v5.4.0

package org.csapi.jr.se.pam;

/**
 * This specifies the values representing the type of change that occurred to the list of watchers.
 *
 */
public final class PAMwatcherChangeType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static PAMwatcherChangeType[] _array = new PAMwatcherChangeType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PAMwatcherChangeType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Periodic reporting, not necessarily a change.
     */
    public static final int _PAM_WATCHERS_PERIODIC =  0;

    /**
     * Periodic reporting, not necessarily a change.
     */
    public static final PAMwatcherChangeType PAM_WATCHERS_PERIODIC = new PAMwatcherChangeType(_PAM_WATCHERS_PERIODIC);

    /**
     * Watchers added to the list.
     */
    public static final int _PAM_WATCHERS_ADDED =  1;

    /**
     * Watchers added to the list.
     */
    public static final PAMwatcherChangeType PAM_WATCHERS_ADDED = new PAMwatcherChangeType(_PAM_WATCHERS_ADDED);

    /**
     * Watchers deleted from the list.
     */
    public static final int _PAM_WATCHERS_DELETED =  2;

    /**
     * Watchers deleted from the list.
     */
    public static final PAMwatcherChangeType PAM_WATCHERS_DELETED = new PAMwatcherChangeType(_PAM_WATCHERS_DELETED);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PAMwatcherChangeType object
     */
    public String getValueText() {
        switch (_value) {
            case _PAM_WATCHERS_PERIODIC:
                return "PAM_WATCHERS_PERIODIC";
            case _PAM_WATCHERS_ADDED:
                return "PAM_WATCHERS_ADDED";
            case _PAM_WATCHERS_DELETED:
                return "PAM_WATCHERS_DELETED";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PAMwatcherChangeType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMwatcherChangeType)) {
            return false;
        }
        PAMwatcherChangeType pAMwatcherChangeType = (PAMwatcherChangeType) o; 
        if(!(this.getValue() == pAMwatcherChangeType.getValue())) {
            return false;
        }
        if (this.hashCode() != pAMwatcherChangeType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMwatcherChangeType

